@@ -89,7 +89,11 @@ def client_ping_response(client):
     False == client is not
 
     """
-    ping_response = subprocess.call(['/sbin/ping', '-c1', client.ip_address])
+    ping_response = subprocess.call(
+        ['/sbin/ping', '-c1', client.ip_address],
+        stdout=subprocess.STDOUT,
+        stderr=subprocess.STDOUT,
+    )
     return ping_response
 
 
